@@ -550,7 +550,8 @@ class ExecutionServer(BaseServer):
             LOGGER.critical("No average speed to report yet.")
             
     def executeJobs(self, data=None):
-        for i in range(0, 100):            
+        deferreds = []
+        for i in range(0, 10):            
             if len(self.job_queue) > 0 and len(self.active_jobs) < self.simultaneous_jobs:
                 job = self.job_queue.pop(0)
                 exposed_function = job["exposed_function"]
@@ -568,9 +569,12 @@ class ExecutionServer(BaseServer):
                 d.addCallback(self._jobCountCallback)
                 d.addErrback(self._jobCountErrback)
                 d.addCallback(self._setNextRequest, uuid, exposed_function["interval"], function_name)
+                deferreds.append(d)
             else:
-                return
-        reactor.callLater(0, self.executeJobs)
+                break
+        if len(deferreds) > 0:
+            d = DeferredList(deferreds)
+            d.addCallback(self.executeJobs())
             
     def _callExposedFunction(
         self, 
